@@ -1,23 +1,13 @@
 /*
  *  DBD::mysql - DBI driver for the mysql database
  *
- *  Copyright (c) 1997, 1998  Jochen Wiedmann
+ *  Copyright (c) 2003       Rudolf Lippan
+ *  Copyright (c) 1997-2003  Jochen Wiedmann
  *
  *  You may distribute this under the terms of either the GNU General Public
- *  License or the Artistic License, as specified in the Perl README file,
- *  with the exception that it cannot be placed on a CD-ROM or similar media
- *  for commercial distribution without the prior approval of the author.
+ *  License or the Artistic License, as specified in the Perl README file.
  *
- *  Author:  Jochen Wiedmann
- *           Am Eisteich 9
- *           72555 Metzingen
- *           Germany
- *
- *           Email: joe@ispsoft.de
- *           Fax: +49 7123 / 14892
- *
- *
- *  $Id: dbdimp.c,v 1.10 2003/08/28 20:22:52 rlippan Exp $
+ *  $Id: dbdimp.c,v 1.13 2004/06/30 17:43:41 rlippan Exp $
  */
 
 
@@ -70,6 +60,7 @@ static int CountParam(char* statement) {
 
     while (c = *ptr++) {
         switch (c) {
+	  case '`':
 	  case '"':
 	  case '\'':
 	    /*
@@ -180,6 +171,7 @@ static char* ParseParam(MYSQL* sock, char* statement, STRLEN *slenPtr,
     j = 0;
     while (j < slen) {
         switch(statement[j]) {
+	  case '`':
 	  case '\'':
 	  case '"':
 	    /*
